@@ -212,8 +212,8 @@ void OreGst::startRecordingCall(
   }
   else
   {
-//    g_object_set(G_OBJECT(speakerSource), "device", "sink.hw0.monitor", NULL);
-    g_object_set(G_OBJECT(speakerSource), "device", "sink.voice", NULL);
+    g_object_set(G_OBJECT(speakerSource), "device", "sink.hw0.monitor", NULL);
+//    g_object_set(G_OBJECT(speakerSource), "device", "sink.voice", NULL);
   }
 
   GstElement *combinedAudio =
